======================
django-dynamic-scraper
======================

Django Dynamic Scraper (DDS) is an app for Django which builds on top of the scraping framework Scrapy and lets
you create and manage Scrapy spiders via the Django admin interface. It was originally developed for german
webtv program site http://fernsehsuche.de.


Documentation
=============
Read more about DDS in the ReadTheDocs documentation:

* http://django-dynamic-scraper.readthedocs.org/

Donations/Support this Project
==============================
I would really like to spent more time for DDS but I am often hold back due to lack of resources
and time. If you want to support development please consider a donation to one of the following
*cryptocurrency accounts*:

======= ==================================
Bitcoin 1P5sLQe4b8ZNCi7AheKL6d1CyzVE3reQUJ
NXT     NXT-M8QX-BWFY-JAGR-44S3P          
======= ==================================

Bitcoin QR-Code:

.. image:: btc_donations.png

Your donation will be used to further improve the software and keep the software up-to-date.
I will use an hourly rate of 20€ (~25$) as a basis and publish the work I did in the following Google Docs spreadsheet:
https://docs.google.com/spreadsheets/d/1LKvLFW786pFdL6AbBlMPu5TnExZooRQ0_naP3TnbGWw/edit?usp=sharing


Getting Help/Updates
====================
There is a mailing list on Google Groups, feel free to ask questions or make suggestions:

* https://groups.google.com/group/django-dynamic-scraper

Infos about new releases and updates on Twitter:

* https://twitter.com/#!/dynamicscraper 
